==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowCustomFormConfigFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowCustomFormConfig}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowCustomFormConfigFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** workflowState (Database column: STATE_ID) */
    static public AttributeDefinition workflowState =
        new AttributeDefinition("workflowState")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("STATE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class);

    /** workflowUserProfile (Database column: USER_PROFILE_ID) */
    static public AttributeDefinition workflowUserProfile =
        new AttributeDefinition("workflowUserProfile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("USER_PROFILE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class);

    /** workflowCustomForm (Database column: WORKFLOW_CUSTOM_FORM_ID) */
    static public AttributeDefinition workflowCustomForm =
        new AttributeDefinition("workflowCustomForm")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("WORKFLOW_CUSTOM_FORM_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowCustomForm.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowCustomForm.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(workflowState.getName(),workflowState);
        map.put(workflowUserProfile.getName(),workflowUserProfile);
        map.put(workflowCustomForm.getName(),workflowCustomForm);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowCustomFormConfigFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowCustomFormConfig}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowCustomFormConfigFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setType(Long.class);

    /** workflowState (Database column: STATE_ID) */
    static public AttributeDefinition workflowState =
        new AttributeDefinition("workflowState")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("STATE_ID")
                .setMandatory(false)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class);

    /** workflowUserProfile (Database column: USER_PROFILE_ID) */
    static public AttributeDefinition workflowUserProfile =
        new AttributeDefinition("workflowUserProfile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("USER_PROFILE_ID")
                .setMandatory(false)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class);

    /** workflowCustomForm (Database column: WORKFLOW_CUSTOM_FORM_ID) */
    static public AttributeDefinition workflowCustomForm =
        new AttributeDefinition("workflowCustomForm")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM_CONFIG")
                .setDatabaseId("WORKFLOW_CUSTOM_FORM_ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowCustomForm.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowCustomForm.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(workflowState.getName(),workflowState);
        map.put(workflowUserProfile.getName(),workflowUserProfile);
        map.put(workflowCustomForm.getName(),workflowCustomForm);

        return map;
    }
}
